@@ -81,8 +81,7 @@ pub mod simple_voter {
     }
 
     #[access_control(ctx.accounts.validate())]
-    pub fn cast_votes(ctx: Context<VoterContext>, vote_side: u8, reason: String) -> ProgramResult {
-        msg!(&reason[..]);
+    pub fn cast_votes(ctx: Context<VoterContext>, vote_side: u8) -> ProgramResult {
         processor::voter::process_cast_votes(ctx, vote_side)
     }
 
